[PATCH 4/4] dbghelp: Use _NT_ALT_SYMBOL_PATH.

Thomas Faber thomas.faber at reactos.org
Sun Nov 14 07:40:38 CST 2021


From ec77426caa512c8c6bbcb20533dc3ac09dbb5206 Mon Sep 17 00:00:00 2001
From: Thomas Faber <thomas.faber at reactos.org>
Date: Fri, 12 Nov 2021 20:17:01 -0500
Subject: dbghelp: Use _NT_ALT_SYMBOL_PATH.

Signed-off-by: Thomas Faber <thomas.faber at reactos.org>
---
 dlls/dbghelp/dbghelp.c       | 6 +++---
 dlls/dbghelp/tests/dbghelp.c | 2 --
 2 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/dlls/dbghelp/tests/dbghelp.c b/dlls/dbghelp/tests/dbghelp.c
index a42e83aa2c8..b7e828281cd 100644
--- a/dlls/dbghelp/tests/dbghelp.c
+++ b/dlls/dbghelp/tests/dbghelp.c
@@ -171,7 +171,6 @@ static void test_search_path(void)
     ok(ret == TRUE, "ret = %d\n", ret);
     ret = SymGetSearchPath(GetCurrentProcess(), search_path, ARRAY_SIZE(search_path));
     ok(ret == TRUE, "ret = %d\n", ret);
-    todo_wine
     ok(!strcmp(search_path, ".;X:\\;Y:\\"), "Got search path '%s', expected '.;X:\\;Y:\\'\n", search_path);
 
     /* With just _NT_ALT_SYMBOL_PATH */
@@ -180,7 +179,6 @@ static void test_search_path(void)
     ok(ret == TRUE, "ret = %d\n", ret);
     ret = SymGetSearchPath(GetCurrentProcess(), search_path, ARRAY_SIZE(search_path));
     ok(ret == TRUE, "ret = %d\n", ret);
-    todo_wine
     ok(!strcmp(search_path, ".;Y:\\"), "Got search path '%s', expected '.;Y:\\'\n", search_path);
 
     /* Restore original search path */
diff --git a/dlls/dbghelp/dbghelp.c b/dlls/dbghelp/dbghelp.c
index b65da2db88b..fc81da9ef54 100644
--- a/dlls/dbghelp/dbghelp.c
+++ b/dlls/dbghelp/dbghelp.c
@@ -183,9 +183,9 @@ static WCHAR* make_default_search_path(void)
     unsigned    alt_sym_path_len;
 
     sym_path_len = GetEnvironmentVariableW(L"_NT_SYMBOL_PATH", NULL, 0);
-    alt_sym_path_len = GetEnvironmentVariableW(L"_NT_ALTERNATE_SYMBOL_PATH", NULL, 0);
+    alt_sym_path_len = GetEnvironmentVariableW(L"_NT_ALT_SYMBOL_PATH", NULL, 0);
 
     /* The default symbol path is ".[;%_NT_SYMBOL_PATH%][;%_NT_ALTERNATE_SYMBOL_PATH%]".
      * If the variables exist, the lengths include a null-terminator. We use that
      * space for the semicolons, and only add the initial dot and the final null. */
     search_path = HeapAlloc(GetProcessHeap(), 0,
@@ -204,7 +204,7 @@ static WCHAR* make_default_search_path(void)
     if (alt_sym_path_len)
     {
         *p++ = L';';
-        GetEnvironmentVariableW(L"_NT_ALTERNATE_SYMBOL_PATH", p, alt_sym_path_len);
+        GetEnvironmentVariableW(L"_NT_ALT_SYMBOL_PATH", p, alt_sym_path_len);
         p += alt_sym_path_len - 1;
     }
     *p = L'\0';
@@ -183,9 +183,9 @@ static WCHAR* make_default_search_path(void)
 
-    /* The default symbol path is ".[;%_NT_SYMBOL_PATH%][;%_NT_ALTERNATE_SYMBOL_PATH%]".
+    /* The default symbol path is ".[;%_NT_SYMBOL_PATH%][;%_NT_ALT_SYMBOL_PATH%]".
      * If the variables exist, the lengths include a null-terminator. We use that
      * space for the semicolons, and only add the initial dot and the final null. */
-- 
2.31.1



More information about the wine-devel mailing list